@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class OperationlogConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
-    name = "operationlogs"
+    name = "drf_operation_log"
