@@ -118,7 +118,7 @@ class OperationLogEntry(models.Model):
             return ["未改动"]
 
         ret = []
-        for field_name, (old_value, new_value) in self.change_message:
+        for field_name, (old_value, new_value) in self.change_message.items():
             message = f'修改{field_name}， 旧值"{old_value}"，新值"{new_value}"'
             ret.append(message)
 
